@@ -33,7 +33,7 @@ Usage::
     list_topics_detection_jobs_paginator: ListTopicsDetectionJobsPaginator = client.get_paginator("list_topics_detection_jobs")
     ```
 """
-from mypy_boto3_comprehend.client import ComprehendClient, ComprehendClient as Client
+from mypy_boto3_comprehend.client import ComprehendClient
 from mypy_boto3_comprehend.paginator import (
     ListDocumentClassificationJobsPaginator,
     ListDocumentClassifiersPaginator,
@@ -45,6 +45,8 @@ from mypy_boto3_comprehend.paginator import (
     ListTopicsDetectionJobsPaginator,
 )
 
+Client = ComprehendClient
+
 
 __all__ = (
     "Client",
